==> packagechart-0.0.5.tgz: package/LineChart.tsx <==
import React, { useEffect, useRef, useState } from "react";
import Chart from "chart.js/auto";

interface ChartData {
  labels: string[];
  datasets: {
    data: number[];
    label: string;
    borderColor: string;
    backgroundColor: string;
    fill: boolean;
  }[];
}

const LineChart: React.FC = () => {
  const [chartData, setChartData] = useState<ChartData | null>(null);
  const chartRef = useRef<Chart | null>(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await fetch("http://localhost:3000/api/data");
        const data = await response.json();
        setChartData(data);
      } catch (error) {
        console.error("Error fetching chart data:", error);
      }
    };

    fetchData();

    // Cleanup function to ensure any existing chart is destroyed when component unmounts
    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, []);

  useEffect(() => {
    if (!chartData) return;

    const canvas = document.getElementById("myChart") as HTMLCanvasElement | null;
    if (canvas) {
      const ctx = canvas.getContext("2d");
      if (ctx) {
        if (chartRef.current) {
          chartRef.current.destroy();
        }
        chartRef.current = new Chart(ctx, {
          type: "line",
          data: chartData,
        });
      }
    }

    // Cleanup function to ensure any existing chart is destroyed when component unmounts
    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, [chartData]);

  return (
    <div>
     
          <canvas id="myChart"></canvas>
        
    </div>
  );
};

export default LineChart;

==> packagechart-0.0.6.tgz: package/LineChart.tsx <==
import React, { useEffect, useRef, useState } from "react";
import Chart from "chart.js/auto";

interface ChartData {
  labels: string[];
  datasets: {
    data: number[];
    label: string;
    borderColor: string;
    backgroundColor: string;
    fill: boolean;
  }[];
}

const LineChart: React.FC = () => {
  const [chartData, setChartData] = useState<ChartData | null>(null);
  const chartRef = useRef<Chart | null>(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await fetch("http://localhost:3000/api/data");
        const data = await response.json();
        setChartData(data);
      } catch (error) {
        console.error("Error fetching chart data:", error);
      }
    };

    fetchData();

    // Cleanup function to ensure any existing chart is destroyed when component unmounts
    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, []);

  useEffect(() => {
    if (!chartData) return;

    const canvas = document.getElementById("chart") as HTMLCanvasElement | null;
    if (canvas) {
      const ctx = canvas.getContext("2d");
      if (ctx) {
        if (chartRef.current) {
          chartRef.current.destroy();
        }
        chartRef.current = new Chart(ctx, {
          type: "line",
          data: chartData,
        });
      }
    }

    // Cleanup function to ensure any existing chart is destroyed when component unmounts
    return () => {
      if (chartRef.current) {
        chartRef.current.destroy();
      }
    };
  }, [chartData]);

  return (
    <div>
     
          <canvas id="chart">
           
          </canvas>
        
    </div>
  );
};

export default LineChart;
